--[[
	Name: GridStatusHostileUnit
	Revision: $Revision: 69831 $
	Developed by: Julith @ Perenolde-EU (billgatesgut@web.de)
	Description: Publishes the state if a Unit is hostile to the player.

	Credits to oodyboo from WoWAce for the idea of this addon.
]]

--{{{ Libraries

local L = AceLibrary("AceLocale-2.2"):new("GridStatusHostileUnit")

--}}}

L:RegisterTranslations("enUS", function()
	return {
		["HostileUnit"] = true,
        ["hostile unit"] = true,
	["is hostile"] = true,
	}
end)

L:RegisterTranslations("koKR", function()
	return {
		["HostileUnit"] = "적대적 유닛",
        ["hostile unit"] = "적대적 유닛",
	["is hostile"] = "적대적",
	}
end)

GridStatusHostileUnit = GridStatus:NewModule("GridStatusHostileUnit")
GridStatusHostileUnit.menuName = L["HostileUnit"]


--{{{ AceDB defaults

GridStatusHostileUnit.defaultDB = {
	unitIsHostile = {
		text = L["is hostile"],
		enable = true,
		priority = 90,
		range = false,
		color = { r = 1, g = 0, b = 0, a = 1 },
		customText = "",
	},
}

--}}}

--{{{ Options
local amountOptions = {

}
--}}}

function GridStatusHostileUnit:OnInitialize()
	self.super.OnInitialize(self)
	self:RegisterStatus("unitIsHostile", L["hostile unit"], amountOptions, true)
end

function GridStatusHostileUnit:OnEnable()
	self:RegisterEvent("UNIT_AURA", "UpdateHostile")
	self:RegisterEvent("UNIT_AURASTATE", "UpdateHostile")
	self:RegisterEvent("UNIT_DYNAMIC_FLAGS", "UpdateHostile")
    self:RegisterEvent("UNIT_FLAGS", "UpdateHostile")
    self:RegisterEvent("UNIT_LOYALTY", "UpdateHostile")
    self:RegisterEvent("Grid_UnitJoined")
	self:RegisterEvent("Grid_UnitChanged")
    self:RegisterEvent("PLAYER_ENTERING_WORLD", "UpdateAllUnits")
end


function GridStatusHostileUnit:UpdateAllUnits()
	local name, status, statusTbl

	for name, status, statusTbl in self.core:CachedStatusIterator("unitIsHostile") do
		self:Grid_UnitJoined(name)
	end
end

function GridStatusHostileUnit:Grid_UnitJoined(name, unitid)
	if unitid then
		self:Update(unitid)
	end
end

function GridStatusHostileUnit:Grid_UnitChanged(name, unitid)
	self:Update(unitid)
end

function GridStatusHostileUnit:Update(unitid)
    if not unitid then
        return
    end

    if not UnitInRaid(unitid) then return end

    local name = UnitName(unitid);

    local settings = self.db.profile.unitIsHostile

    local hostile = false;

    --DEFAULT_CHAT_FRAME:AddMessage(name..":");

    if UnitIsCharmed(unitid) then
        hostile = true;
        --DEFAULT_CHAT_FRAME:AddMessage("charmed");
    end

    if UnitIsEnemy("player", unitid) then
        hostile = true;
        --DEFAULT_CHAT_FRAME:AddMessage("enemy");
    end

    if not UnitIsFriend("player", unitid) then
        hostile = true;
        --DEFAULT_CHAT_FRAME:AddMessage("not friend");
    end

    --if not UnitCanAttack(unitid, unitid.."target") then
    --    hostile = true;
    --    DEFAULT_CHAT_FRAME:AddMessage("not friend");
    --end

    if hostile then
        self.core:SendStatusGained(name, "unitIsHostile",
				    settings.priority,
				    (settings.range and 40),
				    settings.color)
    else
        self.core:SendStatusLost(name, "unitIsHostile")
    end
end

function GridStatusHostileUnit:UpdateHostile(unitid)
	self:Update(unitid)
end



---debug functions
function GridStatusHostileUnit:UNIT_AURA(unitid)

    DEFAULT_CHAT_FRAME:AddMessage("Event: UNIT_AURA");
    self:Update(unitid)
end

function GridStatusHostileUnit:UNIT_AURASTATE(unitid)

    DEFAULT_CHAT_FRAME:AddMessage("Event: UNIT_AURASTATE");
    self:Update(unitid)
end

function GridStatusHostileUnit:UNIT_DYNAMIC_FLAGS(unitid)

    DEFAULT_CHAT_FRAME:AddMessage("Event: UNIT_DYNAMIC_FLAGS");
    self:Update(unitid)
end

function GridStatusHostileUnit:UNIT_FLAGS(unitid)

    DEFAULT_CHAT_FRAME:AddMessage("Event: UNIT_FLAGS");
    self:Update(unitid)
end

function GridStatusHostileUnit:UNIT_LOYALTY(unitid)

    DEFAULT_CHAT_FRAME:AddMessage("Event: UNIT_LOYALTY");
    self:Update(unitid)
end


